@@ -22,7 +22,9 @@ from django.contrib.auth.models import User
 from django.core.urlresolvers import reverse
 from django.db import models
 from django.db.models import F
-from django.db.models.signals import post_syncdb, post_save
+from django.db.models.signals import post_syncdb, post_save, pre_delete, \
+  class_prepared
+from django.template.defaultfilters import slugify
 from django.utils.datastructures import SortedDict
 from django.utils.encoding import smart_unicode
 from django.utils.translation import ugettext_lazy as _
@@ -32,7 +34,7 @@ from sentry.manager import GroupManager, ProjectManager, \
   MetaManager, InstanceMetaManager, SearchDocumentManager, BaseManager
 from sentry.utils import cached_property, \
   MockDjangoRequest
-from sentry.utils.models import Model, GzippedDictField
+from sentry.utils.models import Model, GzippedDictField, update
 from sentry.templatetags.sentry_helpers import truncatechars
 
 __all__ = ('Event', 'Group', 'Project', 'SearchDocument')
@@ -77,13 +79,59 @@ class Option(Model):
     ])
 
 
+class Team(Model):
+    """
+    A team represents a group of individuals which maintain ownership of projects.
+    """
+    slug = models.SlugField(unique=True)
+    name = models.CharField(max_length=64)
+    owner = models.ForeignKey(User)
+
+    objects = BaseManager(cache_fields=(
+        'pk',
+        'slug',
+    ))
+
+    def __unicode__(self):
+        return self.slug
+
+    def save(self, *args, **kwargs):
+        if not self.slug:
+            self.slug = slugify(self.name)
+        super(Team, self).save(*args, **kwargs)
+
+
+class TeamMember(Model):
+    """
+    Identifies relationships between teams and users.
+    """
+    team = models.ForeignKey(Team, related_name="member_set")
+    user = models.ForeignKey(User, related_name="sentry_teammember_set")
+    is_active = models.BooleanField(default=True)
+    type = models.IntegerField(choices=MEMBER_TYPES, default=globals().get(settings.DEFAULT_PROJECT_ACCESS))
+    date_added = models.DateTimeField(default=datetime.now)
+
+    objects = BaseManager()
+
+    class Meta:
+        unique_together = (('team', 'user'),)
+
+    def __unicode__(self):
+        return u'team=%s, user=%s, type=%s' % (self.team_id, self.user_id, self.get_type_display())
+
+
 class Project(Model):
     """
     Projects are permission based namespaces which generally
     are the top level entry point for all data.
+
+    A project may be owned by only a single team, and may or may not
+    have an owner (which is thought of as a project creator).
     """
+    slug = models.SlugField(unique=True, null=True)
     name = models.CharField(max_length=200)
     owner = models.ForeignKey(User, related_name="sentry_owned_project_set", null=True)
+    team = models.ForeignKey(Team, null=True)
     public = models.BooleanField(default=False)
     date_added = models.DateTimeField(default=datetime.now)
     status = models.PositiveIntegerField(default=0, choices=(
@@ -93,11 +141,17 @@ class Project(Model):
 
     objects = ProjectManager(cache_fields=[
         'pk',
+        'slug',
     ])
 
     def __unicode__(self):
         return u'#%s %r' % (self.pk, self.name)
 
+    def save(self, *args, **kwargs):
+        if not self.slug:
+            self.slug = slugify(self.name)
+        super(Project, self).save(*args, **kwargs)
+
     def delete(self):
         # This hadles cascades properly
         # TODO: this doesnt clean up the index
@@ -159,6 +213,42 @@ class Project(Model):
         self.delete()
 
 
+class ProjectKey(Model):
+    project = models.ForeignKey(Project, related_name='key_set')
+    public_key = models.CharField(max_length=32, unique=True, null=True)
+    secret_key = models.CharField(max_length=32, unique=True, null=True)
+    user = models.ForeignKey(User, null=True)
+
+    objects = BaseManager(cache_fields=(
+        'public_key',
+        'secret_key',
+    ))
+
+    def __unicode__(self):
+        return u'project=%s, user=%s' % (self.project_id, self.user_id)
+
+    @classmethod
+    def generate_api_key(cls):
+        return uuid.uuid4().hex
+
+    def save(self, *args, **kwargs):
+        if not self.public_key:
+            self.public_key = ProjectKey.generate_api_key()
+        if not self.secret_key:
+            self.secret_key = ProjectKey.generate_api_key()
+        super(ProjectKey, self).save(*args, **kwargs)
+
+    def get_dsn(self, domain=None, secure=True):
+        urlparts = urlparse.urlparse(settings.URL_PREFIX)
+        return '%s://%s:%s@%s/%s' % (
+            urlparts.scheme,
+            self.public_key,
+            self.secret_key,
+            urlparts.netloc + urlparts.path,
+            self.project_id,
+        )
+
+
 class ProjectOption(Model):
     """
     Project options apply only to an instance of a project.
@@ -180,25 +270,25 @@ class ProjectOption(Model):
         return u'project=%s, key=%s, value=%s' % (self.project_id, self.key, self.value)
 
 
-class PendingProjectMember(Model):
+class PendingTeamMember(Model):
     """
-    Identifies relationships between projects and pending invites.
+    Identifies relationships between teams and pending invites.
     """
-    project = models.ForeignKey(Project, related_name="pending_member_set")
+    team = models.ForeignKey(Team, related_name="pending_member_set")
     email = models.EmailField()
     type = models.IntegerField(choices=MEMBER_TYPES, default=globals().get(settings.DEFAULT_PROJECT_ACCESS))
     date_added = models.DateTimeField(default=datetime.now)
 
     class Meta:
-        unique_together = (('project', 'email'),)
+        unique_together = (('team', 'email'),)
 
     def __unicode__(self):
-        return u'project=%s, email=%s, type=%s' % (self.project_id, self.email, self.get_type_display())
+        return u'team=%s, email=%s, type=%s' % (self.team_id, self.email, self.get_type_display())
 
     @property
     def token(self):
         checksum = md5()
-        for x in (str(self.project_id), self.email, settings.KEY):
+        for x in (str(self.team_id), self.email, settings.KEY):
             checksum.update(x)
         return checksum.hexdigest()
 
@@ -208,7 +298,7 @@ class PendingProjectMember(Model):
 
         context = {
             'email': self.email,
-            'project': self.project,
+            'team': self.team,
             'url': '%s%s' % (settings.URL_PREFIX, reverse('sentry-accept-invite', kwargs={
                 'member_id': self.id,
                 'token': self.token,
@@ -217,7 +307,7 @@ class PendingProjectMember(Model):
         body = render_to_string('sentry/emails/member_invite.txt', context)
 
         try:
-            send_mail('%s Invite to join project: %s' % (settings.EMAIL_SUBJECT_PREFIX, self.project.name),
+            send_mail('%s Invite to join team: %s' % (settings.EMAIL_SUBJECT_PREFIX, self.team.name),
                 body, settings.SERVER_EMAIL, [self.email],
                 fail_silently=False)
         except Exception, e:
@@ -225,52 +315,6 @@ class PendingProjectMember(Model):
             logger.exception(e)
 
 
-class ProjectMember(Model):
-    """
-    Identifies relationships between projects and users, including
-    their API access and permissions.
-    """
-    project = models.ForeignKey(Project, related_name="member_set")
-    user = models.ForeignKey(User, related_name="sentry_project_set")
-    is_active = models.BooleanField(default=True)
-    public_key = models.CharField(max_length=32, unique=True, null=True)
-    secret_key = models.CharField(max_length=32, unique=True, null=True)
-    type = models.IntegerField(choices=MEMBER_TYPES, default=globals().get(settings.DEFAULT_PROJECT_ACCESS))
-    date_added = models.DateTimeField(default=datetime.now)
-
-    objects = BaseManager(cache_fields=[
-        'public_key',
-        'secret_key',
-    ])
-
-    class Meta:
-        unique_together = (('project', 'user'),)
-
-    def __unicode__(self):
-        return u'project=%s, user=%s, type=%s' % (self.project_id, self.user_id, self.get_type_display())
-
-    def save(self, *args, **kwargs):
-        if not self.public_key:
-            self.public_key = ProjectMember.generate_api_key()
-        if not self.secret_key:
-            self.secret_key = ProjectMember.generate_api_key()
-        super(ProjectMember, self).save(*args, **kwargs)
-
-    @classmethod
-    def generate_api_key(cls):
-        return uuid.uuid4().hex
-
-    def get_dsn(self, domain=None, secure=True):
-        urlparts = urlparse.urlparse(settings.URL_PREFIX)
-        return '%s://%s:%s@%s/%s' % (
-            urlparts.scheme,
-            self.public_key,
-            self.secret_key,
-            urlparts.netloc + urlparts.path,
-            self.project_id,
-        )
-
-
 class ProjectDomain(Model):
     """
     Currently unused. Planned for 'trusted domains' for JS apis.
@@ -656,16 +700,16 @@ class MessageIndex(BaseIndex):
 
 ## Register Signals
 
-def register_indexes():
+def register_indexes(**kwargs):
     """
     Grabs all required indexes from filters and registers them.
     """
-    from sentry.filters import Filter
+    from sentry.filters import get_filters
     logger = logging.getLogger('sentry.setup')
-    for cls in (f for f in Filter.objects.all() if f.column.startswith('data__')):
+    for cls in (f for f in get_filters() if f.column.startswith('data__')):
         MessageIndex.objects.register_index(cls.column, index_to='group')
         logger.debug('Registered index for for %r' % cls.column)
-register_indexes()
+class_prepared.connect(register_indexes, sender=MessageIndex)
 
 
 def create_default_project(created_models, verbosity=2, **kwargs):
@@ -701,14 +745,36 @@ def create_default_project(created_models, verbosity=2, **kwargs):
                 print 'done!'
 
 
-def create_project_member_for_owner(instance, created, **kwargs):
+def create_team_for_project(instance, created, **kwargs):
+    if not created:
+        return
+
+    if instance.team:
+        return
+
+    if not instance.owner:
+        return
+
+    update(instance, team=Team.objects.create(
+        owner=instance.owner,
+        name=instance.name,
+        slug=instance.slug,
+    ))
+
+    ProjectKey.objects.get_or_create(
+        project=instance,
+        user=instance.owner,
+    )
+
+
+def create_team_member_for_owner(instance, created, **kwargs):
     if not created:
         return
 
     if not instance.owner:
         return
 
-    instance.member_set.create(
+    instance.member_set.get_or_create(
         user=instance.owner,
         type=globals()[settings.DEFAULT_PROJECT_ACCESS]
     )
@@ -723,6 +789,25 @@ def update_document(instance, created, **kwargs):
         group=instance,
     ).update(status=instance.status)
 
+
+def create_key_for_team_member(instance, created, **kwargs):
+    if not created:
+        return
+
+    for project in instance.team.project_set.all():
+        ProjectKey.objects.get_or_create(
+            project=project,
+            user=instance.user,
+        )
+
+
+def remove_key_for_team_member(instance, **kwargs):
+    for project in instance.team.project_set.all():
+        ProjectKey.objects.filter(
+            project=project,
+            user=instance.user,
+        ).delete()
+
 # Signal registration
 post_syncdb.connect(
     create_default_project,
@@ -730,9 +815,15 @@ post_syncdb.connect(
     weak=False,
 )
 post_save.connect(
-    create_project_member_for_owner,
+    create_team_for_project,
     sender=Project,
-    dispatch_uid="create_project_member_for_owner",
+    dispatch_uid="create_team_for_project",
+    weak=False,
+)
+post_save.connect(
+    create_team_member_for_owner,
+    sender=Team,
+    dispatch_uid="create_team_member_for_owner",
     weak=False,
 )
 post_save.connect(
@@ -741,3 +832,15 @@ post_save.connect(
     dispatch_uid="update_document",
     weak=False,
 )
+post_save.connect(
+    create_key_for_team_member,
+    sender=TeamMember,
+    dispatch_uid="create_key_for_team_member",
+    weak=False,
+)
+pre_delete.connect(
+    remove_key_for_team_member,
+    sender=TeamMember,
+    dispatch_uid="remove_key_for_team_member",
+    weak=False,
+)
