@@ -12,7 +12,7 @@ from django.conf.urls.defaults import *
 
 from sentry.web import api
 from sentry.web.frontend import accounts, generic, groups, events, \
-  projects, admin, docs
+  projects, admin, docs, teams
 
 __all__ = ('urlpatterns',)
 
@@ -45,35 +45,45 @@ urlpatterns = patterns('',
     url(r'^logout/$', accounts.logout, name='sentry-logout'),
     url(r'^account/settings/$', accounts.settings, name='sentry-account-settings'),
 
-    # Management
+    # Teams
 
-    url(r'^projects/$', projects.project_list, name='sentry-project-list'),
-    url(r'^projects/new/$', projects.new_project, name='sentry-new-project'),
-    url(r'^projects/(?P<project_id>\d+)/edit/$', projects.manage_project,
-        name='sentry-manage-project'),
-    url(r'^projects/(?P<project_id>\d+)/plugins/$', projects.manage_plugins,
-        name='sentry-manage-project-plugins'),
-    url(r'^projects/(?P<project_id>\d+)/plugins/(?P<slug>[\w_-]+)/$', projects.configure_project_plugin,
-        name='sentry-configure-project-plugin'),
-    url(r'^projects/(?P<project_id>\d+)/remove/$', projects.remove_project,
-        name='sentry-remove-project'),
-    url(r'^projects/(?P<project_id>\d+)/members/new/$', projects.new_project_member,
-        name='sentry-new-project-member'),
-    url(r'^projects/(?P<project_id>\d+)/members/(?P<member_id>\d+)/edit/$', projects.edit_project_member,
-        name='sentry-edit-project-member'),
-    url(r'^projects/(?P<project_id>\d+)/members/(?P<member_id>\d+)/remove/$', projects.remove_project_member,
-        name='sentry-remove-project-member'),
-    url(r'^projects/(?P<project_id>\d+)/members/(?P<member_id>\d+)/suspend/$', projects.suspend_project_member,
-        name='sentry-suspend-project-member'),
-    url(r'^projects/(?P<project_id>\d+)/members/(?P<member_id>\d+)/restore/$', projects.restore_project_member,
-        name='sentry-restore-project-member'),
-    url(r'^projects/(?P<project_id>\d+)/members/pending/(?P<member_id>\d+)/remove/$', projects.remove_pending_project_member,
-        name='sentry-remove-pending-project-member'),
-    url(r'^projects/(?P<project_id>\d+)/members/pending/(?P<member_id>\d+)/reinvite/$', projects.reinvite_pending_project_member,
-        name='sentry-reinvite-pending-project-member'),
-    url(r'^accept/(?P<member_id>\d+)/(?P<token>\w+)/$', projects.accept_invite,
+    url(r'^account/teams/$', teams.team_list, name='sentry-team-list'),
+    url(r'^account/teams/new/$', teams.create_new_team, name='sentry-new-team'),
+    url(r'^account/teams/(?P<team_slug>[\w_-]+)/edit/$', teams.manage_team,
+        name='sentry-manage-team'),
+    url(r'^account/teams/(?P<team_slug>[\w_-]+)/remove/$', teams.remove_team,
+        name='sentry-remove-team'),
+    url(r'^account/teams/(?P<team_slug>[\w_-]+)/members/new/$', teams.new_team_member,
+        name='sentry-new-team-member'),
+    url(r'^account/teams/(?P<team_slug>[\w_-]+)/members/(?P<member_id>\d+)/edit/$', teams.edit_team_member,
+        name='sentry-edit-team-member'),
+    url(r'^account/teams/(?P<team_slug>[\w_-]+)/members/(?P<member_id>\d+)/remove/$', teams.remove_team_member,
+        name='sentry-remove-team-member'),
+    url(r'^account/teams/(?P<team_slug>[\w_-]+)/members/(?P<member_id>\d+)/suspend/$', teams.suspend_team_member,
+        name='sentry-suspend-team-member'),
+    url(r'^account/teams/(?P<team_slug>[\w_-]+)/members/(?P<member_id>\d+)/restore/$', teams.restore_team_member,
+        name='sentry-restore-team-member'),
+    url(r'^account/teams/(?P<team_slug>[\w_-]+)/members/pending/(?P<member_id>\d+)/remove/$', teams.remove_pending_team_member,
+        name='sentry-remove-pending-team-member'),
+    url(r'^account/teams/(?P<team_slug>[\w_-]+)/members/pending/(?P<member_id>\d+)/reinvite/$', teams.reinvite_pending_team_member,
+        name='sentry-reinvite-pending-team-member'),
+    url(r'^account/teams/(?P<team_slug>[\w_-]+)/projects/new/$', teams.create_new_team_project, name='sentry-new-team-project'),
+    url(r'^accept/(?P<member_id>\d+)/(?P<token>\w+)/$', teams.accept_invite,
         name='sentry-accept-invite'),
 
+    # Projects
+
+    url(r'^account/projects/$', projects.project_list, name='sentry-project-list'),
+    url(r'^account/projects/new/$', projects.new_project, name='sentry-new-project'),
+    url(r'^account/projects/(?P<project_id>\d+)/edit/$', projects.manage_project,
+        name='sentry-manage-project'),
+    url(r'^account/projects/(?P<project_id>\d+)/plugins/$', projects.manage_plugins,
+        name='sentry-manage-project-plugins'),
+    url(r'^account/projects/(?P<project_id>\d+)/plugins/(?P<slug>[\w_-]+)/$', projects.configure_project_plugin,
+        name='sentry-configure-project-plugin'),
+    url(r'^account/projects/(?P<project_id>\d+)/remove/$', projects.remove_project,
+        name='sentry-remove-project'),
+
     # Global
 
     url(r'^$', generic.dashboard, name='sentry'),
